.. _assignednumbers:

Assigned Numbers
================

The ``AssignedNumbers`` object is a convenient way to refer to common Bluetooth-related
Assigned Numbers by using textual names. So, for instance ``AssignedNumbers.firmwareRevisionString``
is a ``UUID`` object for the `Firmware Revision String` characteristic identifier (0x2A26).

The complete list of Bluetooth assigned numbers is given at https://www.bluetooth.com/specifications/assigned-numbers/

The current version of `bluepy3` includes the following defined values::

 alertNotificationService
 batteryLevel
 batteryService
 bloodPressure
 currentTimeService
 cyclingPower
 cyclingSpeedAndCadence
 deviceInformation
 deviceName
 firmwareRevisionString
 genericAccess
 genericAttribute
 glucose
 hardwareRevisionString
 healthThermometer
 heartRate
 humanInterfaceDevice
 immediateAlert
 linkLoss
 locationAndNavigation
 manufacturerNameString
 modelNumberString
 nextDstChangeService
 phoneAlertStatusService
 referenceTimeUpdateService
 runningSpeedAndCadence
 scanParameters
 serialNumberString
 softwareRevisionString
 txPower
 txPowerLevel
 userData
